<?php

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
    add_theme_support( 'woocommerce' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );
}


function codernote_request($query_string ) {
  if ( isset( $query_string['page'] ) ) {
    if ( ''!=$query_string['page'] ) {
      if ( isset( $query_string['name'] ) ) {
        unset( $query_string['name'] ); }
      }
    }
    return $query_string;
}
add_filter('request', 'codernote_request');



add_filter('request', function( $vars ) {
global $wpdb;

if( ! empty( $vars['pagename'] ) || ! empty( $vars['category_name'] ) || ! empty( $vars['name'] ) || ! empty( $vars['attachment'] ) ) {
    $slug = ! empty( $vars['pagename'] ) ? $vars['pagename'] : ( ! empty( $vars['name'] ) ? $vars['name'] : ( !empty( $vars['category_name'] ) ? $vars['category_name'] : $vars['attachment'] ) );
    $exists = $wpdb->get_var( $wpdb->prepare( "SELECT t.term_id FROM $wpdb->terms t LEFT JOIN $wpdb->term_taxonomy tt ON tt.term_id = t.term_id WHERE tt.taxonomy = 'product_cat' AND t.slug = %s" ,array( $slug )));
    if( $exists ){
        $old_vars = $vars;
        $vars = array('product_cat' => $slug );
        if ( !empty( $old_vars['paged'] ) || !empty( $old_vars['page'] ) )
            $vars['paged'] = ! empty( $old_vars['paged'] ) ? $old_vars['paged'] : $old_vars['page'];
        if ( !empty( $old_vars['orderby'] ) )
            $vars['orderby'] = $old_vars['orderby'];
        if ( !empty( $old_vars['order'] ) )
            $vars['order'] = $old_vars['order'];
    }
}
return $vars;
});


add_filter( 'woocommerce_checkout_fields' , 'customize_checkout_fields' );
function customize_checkout_fields( $fields ) {

    unset($fields['billing']['billing_address_1']);
    unset($fields['billing']['billing_company']);
    unset($fields['billing']['billing_address_2']);
    unset($fields['billing']['billing_city']);
    unset($fields['billing']['billing_postcode']);
    unset($fields['billing']['billing_country']);

    return $fields; };

register_nav_menus(
    array(
        'main' => 'Головне меню',
        'mobile' => 'Гамбургер',
        'footer' => 'Футер меню',
    )
);

function theme_add_main( $classes, $args ) {
    if ( $args->theme_location == 'main' ) {
        return preg_replace( '/<li /i', '<li class="nav-item nav-link"', $classes );
    }
    return $classes;
}
add_filter( 'wp_nav_menu_items', 'theme_add_main', 10, 2 );

function theme_add_mobile( $classes, $args ) {
    if ( $args->theme_location == 'mobile' ) {
        return preg_replace( '/<li /i', '<li class="btn btn-primary btn-lg px-4"', $classes );
    }
    return $classes;
}
add_filter( 'wp_nav_menu_items', 'theme_add_mobile', 10, 2 );

function theme_add_footer( $classes, $args ) {
    if ( $args->theme_location == 'footer' ) {
        return preg_replace( '/<li /i', '<li class="btn btn-primary btn-lg px-4 me-sm-3"', $classes );
    }
    return $classes;
}
add_filter( 'wp_nav_menu_items', 'theme_add_footer', 10, 2 );



add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
    return array(
        'width' => 800,
        'height' => 800,
        'crop' => 0,
    );
} );

add_filter( 'woocommerce_product_tabs', 'woo_reorder_tabs', 98 );
function woo_reorder_tabs( $tabs ) {

    $tabs['additional_information']['priority'] = 5;	// Additional information first
    $tabs['description']['priority'] = 10;			// Description second

    return $tabs;
}

add_filter('woocommerce_currency_symbol', 'add_my_currency_symbol', 10, 2);

function add_my_currency_symbol( $currency_symbol, $currency ) {

    switch( $currency ) {

        case 'UAH': $currency_symbol = 'грн.'; break;

    }

    return $currency_symbol;

}

function true_register_wp_sidebars() {

    register_sidebar(
        array(
            'name' => 'Сайдбар у магазині',
            'description' => 'Перетягніть сюди віджети для відображення їх у магазині',
            'id'		 => 'theme-right-sidebar',
            'before_widget'	 => '<div id="%1$s" class="widget %2$s">',
            'after_widget'	 => '</div>',
            'before_title'	 => '<div class="widget-title"><h3>',
            'after_title'	 => '</h3></div>',
        )
    );

    register_sidebar(
        array(
            'id' => 'true_mobile',
            'name' => 'Фільтри мобільна версія',
            'description' => 'Перетягніть сюди віджети для відображення їх у мобільній версії',
            'before_widget' => '<div id="%1$s" class="foot widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        )
    );

    register_sidebar(
        array(
            'id' => 'search-sidebar',
            'name' => 'Пошук',
            'description' => 'Перетягніть сюди віджети для відображення їх у шапці сайту',
            'before_widget' => '<div id="%1$s" class="search-box %2$s">',
            'after_widget' => '</div>',
            'before_title' => '',
            'after_title' => ''
        )
    );

    register_sidebar(
        array(
            'id' => 'blog-sidebar',
            'name' => 'Сайдбар',
            'description' => 'Перетягніть сюди віджети для відображення їх у шапці сайту',
            'before_widget' => '<div id="%1$s" class="blog-sidebar %2$s">',
            'after_widget' => '</div>',
            'before_title'	 => '<div class="widget-title"><h3>',
            'after_title'	 => '</h3></div>',
        )
    );
}

add_filter( 'woocommerce_output_related_products_args', 'jk_related_products_args', 20 );
function jk_related_products_args( $args ) {
    $args['posts_per_page'] = 3; // 4 related products
    return $args;
}

add_action( 'widgets_init', 'true_register_wp_sidebars' );

pll_register_string('Надпис на кнопках - детальніше', 'readmore');
pll_register_string('Надпис на кнопках - фільтр', 'filter');
pll_register_string('Надпис на кнопках - параметри пошуку', 'seachpar');
pll_register_string('В магазин', 'toshop');
pll_register_string('Одиниця виміру', 'each');


add_filter( 'woocommerce_admin_features', function( $features ) {
    return array_values(
        array_filter( $features, function($feature) {
            return $feature !== 'marketing';
        } )
    );
} );

// Дозволити завантажувати заборонені файли
add_filter( 'upload_mimes', 'upload_allow_types' );
function upload_allow_types( $mimes ) {
    // разрешаем новые типы
    $mimes['svg'] = 'image/svg+xml'; // поддержка SVG
    $mimes['doc']  = 'application/msword';
    $mimes['webp'] = 'image/webp';

    // отключаем имеющиеся
    unset( $mimes['mp4a'] );

    return $mimes;
}
// Дозволити завантажувати заборонені файли

/**
 * Отключить emoji
 */
function mhdn_disable_emoji() {
    remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
    remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
    remove_action( 'wp_print_styles', 'print_emoji_styles' );
    remove_action( 'admin_print_styles', 'print_emoji_styles' );
    remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
    remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
    remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
    add_filter( 'tiny_mce_plugins', 'mhdn_disable_tinymce_emoji' );
}
add_action( 'init', 'mhdn_disable_emoji', 1 );
// Ліміт у короткому тексті посту
function custom_excerpt_length( $length ) {
    return 7;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/**
 * Отключить плагин tinymce emoji
 */
function mhdn_disable_tinymce_emoji( $plugins ) {
    return array_diff( $plugins, array( 'wpemoji' ) );
}



?>